"use client"

import * as React from "react"
import { Slot } from "@radix-ui/react-slot"
import { VariantProps, cva } from "class-variance-authority"
import { PanelLeftIcon } from "lucide-react"

import { useIsMobile } from "@/hooks/use-mobile"
import { cn } from "@/lib/utils"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Separator } from "@/components/ui/separator"
import {
  Sheet,
  SheetContent,
  SheetDescription,
  SheetHeader,
  SheetTitle,
} from "@/components/ui/sheet"
import { Skeleton } from "@/components/ui/skeleton"
import {
  Tooltip,
  TooltipContent,
  TooltipProvider,
  TooltipTrigger,
} from "@/components/ui/tooltip"

const SIDEBAR_COOKIE_NAME = "sidebar_state"
const SIDEBAR_COOKIE_MAX_AGE = 60 * 60 * 24 * 7
const SIDEBAR_WIDTH = "16rem"
const SIDEBAR_WIDTH_MOBILE = "18rem"
const SIDEBAR_WIDTH_ICON = "3rem"
const SIDEBAR_KEYBOARD_SHORTCUT = "b"

type SidebarContextProps = {
  state: "expanded" | "collapsed"
  open: boolean
  setOpen: (open: boolean) => void
  openMobile: boolean
  setOpenMobile: (open: boolean) => void
  isMobile: boolean
  toggleSidebar: () => void
}

const SidebarContext = React.createContext<SidebarContextProps | null>(null)

function useSidebar() {
  const context = React.useContext(SidebarContext)
  if (!context) {
    throw new Error("useSidebar must be used within a SidebarProvider.")
  }

  return context
}

function SidebarProvider({
  defaultOpen = true,
  open: openProp,
  onOpenChange: setOpenProp,
  className,
  style,
  children,
  ...props
}: React.ComponentProps<"div"> & {
  defaultOpen?: boolean
  open?: boolean
  onOpenChange?: (open: boolean) => void
}) {
  const isMobile = useIsMobile()
  const [openMobile, setOpenMobile] = React.useState(false)

  // This is the internal state of the sidebar.
  // We use openProp and setOpenProp for control from outside the component.
  const [_open, _setOpen] = React.useState(defaultOpen)
  const open = openProp ?? _open
  const setOpen = React.useCallback(
    (value: boolean | ((value: boolean) => boolean)) => {
      const openState = typeof value === "function" ? value(open) : value
      if (setOpenProp) {
        setOpenProp(openState)
      } else {
        _setOpen(openState)
      }

      // This sets the cookie to keep the sidebar state.
      document.cookie = `${SIDEBAR_COOKIE_NAME}=${openState}; path=/; max-age=${SIDEBAR_COOKIE_MAX_AGE}`
    },
    [setOpenProp, open]
  )

  // Helper to toggle the sidebar.
  const toggleSidebar = React.useCallback(() => {
    return isMobile ? setOpenMobile((open) => !open) : setOpen((open) => !open)
  }, [isMobile, setOpen, setOpenMobile])

  // Adds a keyboard shortcut to toggle the sidebar.
  React.useEffect(() => {
    const handleKeyDown = (event: KeyboardEvent) => {
      if (
        event.key === SIDEBAR_KEYBOARD_SHORTCUT &&
        (event.metaKey || event.ctrlKey)
      ) {
        event.preventDefault()
        toggleSidebar()
      }
    }

    window.addEventListener("keydown", handleKeyDown)
    return () => window.removeEventListener("keydown", handleKeyDown)
  }, [toggleSidebar])

  // We add a state so that we can do data-state="expanded" or "collapsed".
  // This makes it easier to style the sidebar with Tailwind classes.
  const state = open ? "expanded" : "collapsed"

  const contextValue = React.useMemo<SidebarContextProps>(
    () => ({
      state,
      open,
      setOpen,
      isMobile,
      openMobile,
      setOpenMobile,
      toggleSidebar,
    }),
    [state, open, setOpen, isMobile, openMobile, setOpenMobile, toggleSidebar]
  )

  return (
    <SidebarContext.Provider value={contextValue}>
      <TooltipProvider delayDuration={0}>
        <div
          data-slot="sidebar-wrapper"
          style={
            {
              "--sidebar-width": SIDEBAR_WIDTH,
              "--sidebar-width-icon": SIDEBAR_WIDTH_ICON,
              ...style,
            } as React.CSSProperties
          }
          className={cn(
            "rf:group/sidebar-wrapper rf:has-data-[variant=inset]:bg-sidebar rf:flex rf:min-h-svh rf:w-full",
            className
          )}
          {...props}
        >
          {children}
        </div>
      </TooltipProvider>
    </SidebarContext.Provider>
  )
}

function Sidebar({
  side = "left",
  variant = "sidebar",
  collapsible = "offcanvas",
  className,
  children,
  ...props
}: React.ComponentProps<"div"> & {
  side?: "left" | "right"
  variant?: "sidebar" | "floating" | "inset"
  collapsible?: "offcanvas" | "icon" | "none"
}) {
  const { isMobile, state, openMobile, setOpenMobile } = useSidebar()

  if (collapsible === "none") {
    return (
      <div
        data-slot="sidebar"
        className={cn(
          "rf:bg-sidebar rf:text-sidebar-foreground rf:flex rf:h-full rf:w-(--sidebar-width) rf:flex-col",
          className
        )}
        {...props}
      >
        {children}
      </div>
    )
  }

  if (isMobile) {
    return (
      <Sheet open={openMobile} onOpenChange={setOpenMobile} {...props}>
        <SheetContent
          data-sidebar="sidebar"
          data-slot="sidebar"
          data-mobile="true"
          className="rf:bg-sidebar rf:text-sidebar-foreground rf:w-(--sidebar-width) rf:p-0 rf:[&>button]:hidden"
          style={
            {
              "--sidebar-width": SIDEBAR_WIDTH_MOBILE,
            } as React.CSSProperties
          }
          side={side}
        >
          <SheetHeader className="rf:sr-only">
            <SheetTitle>Sidebar</SheetTitle>
            <SheetDescription>Displays the mobile sidebar.</SheetDescription>
          </SheetHeader>
          <div className="rf:flex rf:h-full rf:w-full rf:flex-col">{children}</div>
        </SheetContent>
      </Sheet>
    )
  }

  return (
    <div
      className="rf:group rf:peer rf:text-sidebar-foreground rf:hidden rf:md:block"
      data-state={state}
      data-collapsible={state === "collapsed" ? collapsible : ""}
      data-variant={variant}
      data-side={side}
      data-slot="sidebar"
    >
      {/* This is what handles the sidebar gap on desktop */}
      <div
        data-slot="sidebar-gap"
        className={cn(
          "rf:relative rf:w-(--sidebar-width) rf:bg-transparent rf:transition-[width] rf:duration-200 rf:ease-linear",
          "rf:group-data-[collapsible=offcanvas]:w-0",
          "rf:group-data-[side=right]:rotate-180",
          variant === "floating" || variant === "inset"
            ? "rf:group-data-[collapsible=icon]:w-[calc(var(--sidebar-width-icon)+(--spacing(4)))]"
            : "rf:group-data-[collapsible=icon]:w-(--sidebar-width-icon)"
        )}
      />
      <div
        data-slot="sidebar-container"
        className={cn(
          "rf:fixed rf:inset-y-0 rf:z-10 rf:hidden rf:h-svh rf:w-(--sidebar-width) rf:transition-[left,right,width] rf:duration-200 rf:ease-linear rf:md:flex",
          side === "left"
            ? "rf:left-0 rf:group-data-[collapsible=offcanvas]:left-[calc(var(--sidebar-width)*-1)]"
            : "rf:right-0 rf:group-data-[collapsible=offcanvas]:right-[calc(var(--sidebar-width)*-1)]",
          // Adjust the padding for floating and inset variants.
          variant === "floating" || variant === "inset"
            ? "rf:p-2 rf:group-data-[collapsible=icon]:w-[calc(var(--sidebar-width-icon)+(--spacing(4))+2px)]"
            : "rf:group-data-[collapsible=icon]:w-(--sidebar-width-icon) rf:group-data-[side=left]:border-r rf:group-data-[side=right]:border-l",
          className
        )}
        {...props}
      >
        <div
          data-sidebar="sidebar"
          data-slot="sidebar-inner"
          className="rf:bg-sidebar rf:group-data-[variant=floating]:border-sidebar-border rf:flex rf:h-full rf:w-full rf:flex-col rf:group-data-[variant=floating]:rounded-lg rf:group-data-[variant=floating]:border rf:group-data-[variant=floating]:shadow-sm"
        >
          {children}
        </div>
      </div>
    </div>
  )
}

function SidebarTrigger({
  className,
  onClick,
  ...props
}: React.ComponentProps<typeof Button>) {
  const { toggleSidebar } = useSidebar()

  return (
    <Button
      data-sidebar="trigger"
      data-slot="sidebar-trigger"
      variant="ghost"
      size="icon"
      className={cn("rf:size-7", className)}
      onClick={(event) => {
        onClick?.(event)
        toggleSidebar()
      }}
      {...props}
    >
      <PanelLeftIcon />
      <span className="rf:sr-only">Toggle Sidebar</span>
    </Button>
  )
}

function SidebarRail({ className, ...props }: React.ComponentProps<"button">) {
  const { toggleSidebar } = useSidebar()

  return (
    <button
      data-sidebar="rail"
      data-slot="sidebar-rail"
      aria-label="Toggle Sidebar"
      tabIndex={-1}
      onClick={toggleSidebar}
      title="Toggle Sidebar"
      className={cn(
        "rf:hover:after:bg-sidebar-border rf:absolute rf:inset-y-0 rf:z-20 rf:hidden rf:w-4 rf:-translate-x-1/2 rf:transition-all rf:ease-linear rf:group-data-[side=left]:-right-4 rf:group-data-[side=right]:left-0 rf:after:absolute rf:after:inset-y-0 rf:after:left-1/2 rf:after:w-[2px] rf:sm:flex",
        "rf:in-data-[side=left]:cursor-w-resize rf:in-data-[side=right]:cursor-e-resize",
        "rf:[[data-side=left][data-state=collapsed]_&]:cursor-e-resize rf:[[data-side=right][data-state=collapsed]_&]:cursor-w-resize",
        "rf:hover:group-data-[collapsible=offcanvas]:bg-sidebar rf:group-data-[collapsible=offcanvas]:translate-x-0 rf:group-data-[collapsible=offcanvas]:after:left-full",
        "rf:[[data-side=left][data-collapsible=offcanvas]_&]:-right-2",
        "rf:[[data-side=right][data-collapsible=offcanvas]_&]:-left-2",
        className
      )}
      {...props}
    />
  )
}

function SidebarInset({ className, ...props }: React.ComponentProps<"main">) {
  return (
    <main
      data-slot="sidebar-inset"
      className={cn(
        "rf:bg-background rf:relative rf:flex rf:w-full rf:flex-1 rf:flex-col",
        "rf:md:peer-data-[variant=inset]:m-2 rf:md:peer-data-[variant=inset]:ml-0 rf:md:peer-data-[variant=inset]:rounded-xl rf:md:peer-data-[variant=inset]:shadow-sm rf:md:peer-data-[variant=inset]:peer-data-[state=collapsed]:ml-2",
        className
      )}
      {...props}
    />
  )
}

function SidebarInput({
  className,
  ...props
}: React.ComponentProps<typeof Input>) {
  return (
    <Input
      data-slot="sidebar-input"
      data-sidebar="input"
      className={cn("rf:bg-background rf:h-8 rf:w-full rf:shadow-none", className)}
      {...props}
    />
  )
}

function SidebarHeader({ className, ...props }: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sidebar-header"
      data-sidebar="header"
      className={cn("rf:flex rf:flex-col rf:gap-2 rf:p-2", className)}
      {...props}
    />
  )
}

function SidebarFooter({ className, ...props }: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sidebar-footer"
      data-sidebar="footer"
      className={cn("rf:flex rf:flex-col rf:gap-2 rf:p-2", className)}
      {...props}
    />
  )
}

function SidebarSeparator({
  className,
  ...props
}: React.ComponentProps<typeof Separator>) {
  return (
    <Separator
      data-slot="sidebar-separator"
      data-sidebar="separator"
      className={cn("rf:bg-sidebar-border rf:mx-2 rf:w-auto", className)}
      {...props}
    />
  )
}

function SidebarContent({ className, ...props }: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sidebar-content"
      data-sidebar="content"
      className={cn(
        "rf:flex rf:min-h-0 rf:flex-1 rf:flex-col rf:gap-2 rf:overflow-auto rf:group-data-[collapsible=icon]:overflow-hidden",
        className
      )}
      {...props}
    />
  )
}

function SidebarGroup({ className, ...props }: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sidebar-group"
      data-sidebar="group"
      className={cn("rf:relative rf:flex rf:w-full rf:min-w-0 rf:flex-col rf:p-2", className)}
      {...props}
    />
  )
}

function SidebarGroupLabel({
  className,
  asChild = false,
  ...props
}: React.ComponentProps<"div"> & { asChild?: boolean }) {
  const Comp = asChild ? Slot : "div"

  return (
    <Comp
      data-slot="sidebar-group-label"
      data-sidebar="group-label"
      className={cn(
        "rf:text-sidebar-foreground/70 rf:ring-sidebar-ring rf:flex rf:h-8 rf:shrink-0 rf:items-center rf:rounded-md rf:px-2 rf:text-xs rf:font-medium rf:outline-hidden rf:transition-[margin,opacity] rf:duration-200 rf:ease-linear rf:focus-visible:ring-2 rf:[&>svg]:size-4 rf:[&>svg]:shrink-0",
        "rf:group-data-[collapsible=icon]:-mt-8 rf:group-data-[collapsible=icon]:opacity-0",
        className
      )}
      {...props}
    />
  )
}

function SidebarGroupAction({
  className,
  asChild = false,
  ...props
}: React.ComponentProps<"button"> & { asChild?: boolean }) {
  const Comp = asChild ? Slot : "button"

  return (
    <Comp
      data-slot="sidebar-group-action"
      data-sidebar="group-action"
      className={cn(
        "rf:text-sidebar-foreground rf:ring-sidebar-ring rf:hover:bg-sidebar-accent rf:hover:text-sidebar-accent-foreground rf:absolute rf:top-3.5 rf:right-3 rf:flex rf:aspect-square rf:w-5 rf:items-center rf:justify-center rf:rounded-md rf:p-0 rf:outline-hidden rf:transition-transform rf:focus-visible:ring-2 rf:[&>svg]:size-4 rf:[&>svg]:shrink-0",
        // Increases the hit area of the button on mobile.
        "rf:after:absolute rf:after:-inset-2 rf:md:after:hidden",
        "rf:group-data-[collapsible=icon]:hidden",
        className
      )}
      {...props}
    />
  )
}

function SidebarGroupContent({
  className,
  ...props
}: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sidebar-group-content"
      data-sidebar="group-content"
      className={cn("rf:w-full rf:text-sm", className)}
      {...props}
    />
  )
}

function SidebarMenu({ className, ...props }: React.ComponentProps<"ul">) {
  return (
    <ul
      data-slot="sidebar-menu"
      data-sidebar="menu"
      className={cn("rf:flex rf:w-full rf:min-w-0 rf:flex-col rf:gap-1", className)}
      {...props}
    />
  )
}

function SidebarMenuItem({ className, ...props }: React.ComponentProps<"li">) {
  return (
    <li
      data-slot="sidebar-menu-item"
      data-sidebar="menu-item"
      className={cn("rf:group/menu-item rf:relative", className)}
      {...props}
    />
  )
}

const sidebarMenuButtonVariants = cva(
  "rf:peer/menu-button rf:flex rf:w-full rf:items-center rf:gap-2 rf:overflow-hidden rf:rounded-md rf:p-2 rf:text-left rf:text-sm rf:outline-hidden rf:ring-sidebar-ring rf:transition-[width,height,padding] rf:hover:bg-sidebar-accent rf:hover:text-sidebar-accent-foreground rf:focus-visible:ring-2 rf:active:bg-sidebar-accent rf:active:text-sidebar-accent-foreground rf:disabled:pointer-events-none rf:disabled:opacity-50 rf:group-has-data-[sidebar=menu-action]/menu-item:pr-8 rf:aria-disabled:pointer-events-none rf:aria-disabled:opacity-50 rf:data-[active=true]:bg-sidebar-accent rf:data-[active=true]:font-medium rf:data-[active=true]:text-sidebar-accent-foreground rf:data-[state=open]:hover:bg-sidebar-accent rf:data-[state=open]:hover:text-sidebar-accent-foreground rf:group-data-[collapsible=icon]:size-8! rf:group-data-[collapsible=icon]:p-2! rf:[&>span:last-child]:truncate rf:[&>svg]:size-4 rf:[&>svg]:shrink-0",
  {
    variants: {
      variant: {
        default: "rf:hover:bg-sidebar-accent rf:hover:text-sidebar-accent-foreground",
        outline:
          "rf:bg-background rf:shadow-[0_0_0_1px_hsl(var(--sidebar-border))] rf:hover:bg-sidebar-accent rf:hover:text-sidebar-accent-foreground rf:hover:shadow-[0_0_0_1px_hsl(var(--sidebar-accent))]",
      },
      size: {
        default: "rf:h-8 rf:text-sm",
        sm: "rf:h-7 rf:text-xs",
        lg: "rf:h-12 rf:text-sm rf:group-data-[collapsible=icon]:p-0!",
      },
    },
    defaultVariants: {
      variant: "default",
      size: "default",
    },
  }
)

function SidebarMenuButton({
  asChild = false,
  isActive = false,
  variant = "default",
  size = "default",
  tooltip,
  className,
  ...props
}: React.ComponentProps<"button"> & {
  asChild?: boolean
  isActive?: boolean
  tooltip?: string | React.ComponentProps<typeof TooltipContent>
} & VariantProps<typeof sidebarMenuButtonVariants>) {
  const Comp = asChild ? Slot : "button"
  const { isMobile, state } = useSidebar()

  const button = (
    <Comp
      data-slot="sidebar-menu-button"
      data-sidebar="menu-button"
      data-size={size}
      data-active={isActive}
      className={cn(sidebarMenuButtonVariants({ variant, size }), className)}
      {...props}
    />
  )

  if (!tooltip) {
    return button
  }

  if (typeof tooltip === "string") {
    tooltip = {
      children: tooltip,
    }
  }

  return (
    <Tooltip>
      <TooltipTrigger asChild>{button}</TooltipTrigger>
      <TooltipContent
        side="right"
        align="center"
        hidden={state !== "collapsed" || isMobile}
        {...tooltip}
      />
    </Tooltip>
  )
}

function SidebarMenuAction({
  className,
  asChild = false,
  showOnHover = false,
  ...props
}: React.ComponentProps<"button"> & {
  asChild?: boolean
  showOnHover?: boolean
}) {
  const Comp = asChild ? Slot : "button"

  return (
    <Comp
      data-slot="sidebar-menu-action"
      data-sidebar="menu-action"
      className={cn(
        "rf:text-sidebar-foreground rf:ring-sidebar-ring rf:hover:bg-sidebar-accent rf:hover:text-sidebar-accent-foreground rf:peer-hover/menu-button:text-sidebar-accent-foreground rf:absolute rf:top-1.5 rf:right-1 rf:flex rf:aspect-square rf:w-5 rf:items-center rf:justify-center rf:rounded-md rf:p-0 rf:outline-hidden rf:transition-transform rf:focus-visible:ring-2 rf:[&>svg]:size-4 rf:[&>svg]:shrink-0",
        // Increases the hit area of the button on mobile.
        "rf:after:absolute rf:after:-inset-2 rf:md:after:hidden",
        "rf:peer-data-[size=sm]/menu-button:top-1",
        "rf:peer-data-[size=default]/menu-button:top-1.5",
        "rf:peer-data-[size=lg]/menu-button:top-2.5",
        "rf:group-data-[collapsible=icon]:hidden",
        showOnHover &&
          "rf:peer-data-[active=true]/menu-button:text-sidebar-accent-foreground rf:group-focus-within/menu-item:opacity-100 rf:group-hover/menu-item:opacity-100 rf:data-[state=open]:opacity-100 rf:md:opacity-0",
        className
      )}
      {...props}
    />
  )
}

function SidebarMenuBadge({
  className,
  ...props
}: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sidebar-menu-badge"
      data-sidebar="menu-badge"
      className={cn(
        "rf:text-sidebar-foreground rf:pointer-events-none rf:absolute rf:right-1 rf:flex rf:h-5 rf:min-w-5 rf:items-center rf:justify-center rf:rounded-md rf:px-1 rf:text-xs rf:font-medium rf:tabular-nums rf:select-none",
        "rf:peer-hover/menu-button:text-sidebar-accent-foreground rf:peer-data-[active=true]/menu-button:text-sidebar-accent-foreground",
        "rf:peer-data-[size=sm]/menu-button:top-1",
        "rf:peer-data-[size=default]/menu-button:top-1.5",
        "rf:peer-data-[size=lg]/menu-button:top-2.5",
        "rf:group-data-[collapsible=icon]:hidden",
        className
      )}
      {...props}
    />
  )
}

function SidebarMenuSkeleton({
  className,
  showIcon = false,
  ...props
}: React.ComponentProps<"div"> & {
  showIcon?: boolean
}) {
  // Random width between 50 to 90%.
  const width = React.useMemo(() => {
    return `${Math.floor(Math.random() * 40) + 50}%`
  }, [])

  return (
    <div
      data-slot="sidebar-menu-skeleton"
      data-sidebar="menu-skeleton"
      className={cn("rf:flex rf:h-8 rf:items-center rf:gap-2 rf:rounded-md rf:px-2", className)}
      {...props}
    >
      {showIcon && (
        <Skeleton
          className="rf:size-4 rf:rounded-md"
          data-sidebar="menu-skeleton-icon"
        />
      )}
      <Skeleton
        className="rf:h-4 rf:max-w-(--skeleton-width) rf:flex-1"
        data-sidebar="menu-skeleton-text"
        style={
          {
            "--skeleton-width": width,
          } as React.CSSProperties
        }
      />
    </div>
  )
}

function SidebarMenuSub({ className, ...props }: React.ComponentProps<"ul">) {
  return (
    <ul
      data-slot="sidebar-menu-sub"
      data-sidebar="menu-sub"
      className={cn(
        "rf:border-sidebar-border rf:mx-3.5 rf:flex rf:min-w-0 rf:translate-x-px rf:flex-col rf:gap-1 rf:border-l rf:px-2.5 rf:py-0.5",
        "rf:group-data-[collapsible=icon]:hidden",
        className
      )}
      {...props}
    />
  )
}

function SidebarMenuSubItem({
  className,
  ...props
}: React.ComponentProps<"li">) {
  return (
    <li
      data-slot="sidebar-menu-sub-item"
      data-sidebar="menu-sub-item"
      className={cn("rf:group/menu-sub-item rf:relative", className)}
      {...props}
    />
  )
}

function SidebarMenuSubButton({
  asChild = false,
  size = "md",
  isActive = false,
  className,
  ...props
}: React.ComponentProps<"a"> & {
  asChild?: boolean
  size?: "sm" | "md"
  isActive?: boolean
}) {
  const Comp = asChild ? Slot : "a"

  return (
    <Comp
      data-slot="sidebar-menu-sub-button"
      data-sidebar="menu-sub-button"
      data-size={size}
      data-active={isActive}
      className={cn(
        "rf:text-sidebar-foreground rf:ring-sidebar-ring rf:hover:bg-sidebar-accent rf:hover:text-sidebar-accent-foreground rf:active:bg-sidebar-accent rf:active:text-sidebar-accent-foreground rf:[&>svg]:text-sidebar-accent-foreground rf:flex rf:h-7 rf:min-w-0 rf:-translate-x-px rf:items-center rf:gap-2 rf:overflow-hidden rf:rounded-md rf:px-2 rf:outline-hidden rf:focus-visible:ring-2 rf:disabled:pointer-events-none rf:disabled:opacity-50 rf:aria-disabled:pointer-events-none rf:aria-disabled:opacity-50 rf:[&>span:last-child]:truncate rf:[&>svg]:size-4 rf:[&>svg]:shrink-0",
        "rf:data-[active=true]:bg-sidebar-accent rf:data-[active=true]:text-sidebar-accent-foreground",
        size === "sm" && "rf:text-xs",
        size === "md" && "rf:text-sm",
        "rf:group-data-[collapsible=icon]:hidden",
        className
      )}
      {...props}
    />
  )
}

export {
  Sidebar,
  SidebarContent,
  SidebarFooter,
  SidebarGroup,
  SidebarGroupAction,
  SidebarGroupContent,
  SidebarGroupLabel,
  SidebarHeader,
  SidebarInput,
  SidebarInset,
  SidebarMenu,
  SidebarMenuAction,
  SidebarMenuBadge,
  SidebarMenuButton,
  SidebarMenuItem,
  SidebarMenuSkeleton,
  SidebarMenuSub,
  SidebarMenuSubButton,
  SidebarMenuSubItem,
  SidebarProvider,
  SidebarRail,
  SidebarSeparator,
  SidebarTrigger,
  useSidebar,
}
