<?php

namespace Drupal\react_flow\Controller;

use Drupal\Component\Utility\Crypt;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\Core\Render\HtmlResponse;
use Drupal\Core\Render\RenderContext;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for the React Flow application.
 */
class ReactFlowController {

  /**
   * Constructs a controller instance.
   *
   * @param \Drupal\Core\Render\RendererInterface $renderer
   */
  public function __construct(
    protected readonly RendererInterface $renderer,
  ) {}

  /**
   * Callback for the 'react_flow.react_flow'-route.
   *
   * @return \Drupal\Core\Render\HtmlResponse|void
   *   Returns an HTML response for initiating the React app.
   */
  public function __invoke() {
    $response = new HtmlResponse('', Response::HTTP_OK, ['Content-Type' => 'text/html; charset=utf-8']);

    $placeholder_token = Crypt::randomBytesBase64(55);

    $element = [
      '#theme' => 'react_flow__decoupled',
      '#cache' => [
        // Add the 'rendered' cache tag as this response is not processed by
        // \Drupal\Core\Render\MainContent\HtmlRenderer::renderResponse().
        'tags' => ['rendered'],
      ],
      '#attached' => [
        'html_response_attachment_placeholders' => [
          'styles' => '<css-placeholder token="' . $placeholder_token . '">',
          'scripts' => '<js-placeholder token="' . $placeholder_token . '">',
          'scripts_bottom' => '<js-bottom-placeholder token="' . $placeholder_token . '">',
        ],
        'drupalSettings' => [
          'rf' => [
            'devMode' => TRUE,
          ],
        ],
      ],
      '#placeholder_token' => $placeholder_token,
    ];
    $context = new RenderContext();
    $content = $this->renderer->executeInRenderContext($context, function () use ($element) {
      return $this->renderer->render($element);
    });

    $response
      ->setContent($content)
      ->setAttachments($element['#attached'])
      ->addCacheableDependency(CacheableMetadata::createFromRenderArray($element));

    // Modules and themes implementing hook_preprocess_react_flow__decoupled()
    // can add additional #cache and #attachments to a render array. If this
    // occurs, the render context won't be empty, and we need to ensure the
    // added metadata is bubbled up to the response.
    // @see \Drupal\Core\Theme\ThemeManager::render()
    if (!$context->isEmpty()) {
      $bubbleable_metadata = $context->pop();
      assert($bubbleable_metadata instanceof BubbleableMetadata);
      $response->addCacheableDependency($bubbleable_metadata);
      $response->addAttachments($bubbleable_metadata->getAttachments());
    }

    return $response;
  }

}
